pub struct Config {
pub shared_config: SharedConfig,
pub kotlin_config: KotlinConfig,
pub demo_gen_config: DemoConfig,
pub js_config: JsConfig,
pub cpp_config: CppConfig,
pub language_overrides: HashMap<String, Value>,
}Fields
kotlin_config: KotlinConfigdemo_gen_config: DemoConfigjs_config: JsConfigcpp_config: CppConfiglanguage_overrides: HashMap<String, Value>Any language can override what’s in SharedConfig. This is a structure that holds information about those specific overrides. Config will update SharedConfig based on the current language.
Implementations
Sourceimpl Config
impl Config
pub fn set(&mut self, key: &str, value: Value)
pub fn get_overridden(self, target_language: &str) -> Self
Sourcepub fn read_file(&mut self, path: &Path) -> Result<(), String>
pub fn read_file(&mut self, path: &Path) -> Result<(), String>
Given a filepath, read TOML formatted config settings from it (and modify the current Config struct from the read)
Sourcepub fn read_cli_settings(&mut self, settings: Vec<String>)
pub fn read_cli_settings(&mut self, settings: Vec<String>)
Given a vector of strings with the format config.setting = value, modify the Config struct appropriately.