ErrorStore

Struct ErrorStore 

pub struct ErrorStore<'tcx, E> { /* private fields */ }
This type acts as a “store” for errors, which can be appended to. Keeps track of the context in which an error was generated.

You can use [set_context_ty()] and [set_context_method()] to set the context as a type or method. They will return scope guards that will automatically pop the stack once they go out of scope, so you don’t have to worry about errors originating from code that does not set a context.

Implementations

Source

impl<'tcx, E> ErrorStore<'tcx, E>

pub fn set_context_ty<'a>( &'a self, ty: Cow<'tcx, str>, ) -> ErrorContextGuard<'a, 'tcx, E>

Set the context to a named type. Will return a scope guard that will automatically clear the context on drop.

pub fn set_context_method<'a>( &'a self, method: Cow<'tcx, str>, ) -> ErrorContextGuard<'a, 'tcx, E>

Set the context to a named method. Will return a scope guard that will automatically clear the context on drop.

pub fn push_error(&self, error: E)

pub fn take_all(&self) -> Vec<(impl Display + 'tcx, E)>